@@ -7,11 +7,14 @@
 typedef struct _ZAttachTCPParams
 {
   gint timeout;
+  gboolean loose;
+  gint tos;
 } ZAttachTCPParams;
 
 typedef struct _ZAttachUDPParams
 {
-  gchar *tracker;
+  gboolean loose;
+  gint tos;
 } ZAttachUDPParams;
 
 typedef union _ZAttachParams
